package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"````````!``````````'"Q````
M`````````$``.``)`$``'``;``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````-"=````````T)T`````````
M`"````````$````&````D*L```````"0JR```````)"K(```````D`0`````
M```8%0``````````(````````@````8```"XJP```````+BK(```````N*L@
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````Z)8```````#HE@```````.B6````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````)"K````````D*L@``````"0JR``
M`````'`$````````<`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,````"``````````0`
M```4`````P```$=.50">?/8ST;ZSZT\8PZAJJ@U,$1U7,1$```!$````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!$````
M2````$P```!-````5````%4```!7````6P```%P`````````7@```&$```!B
M````8P``````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````$0$``!(`````
M````````````````````YP$``!(`````````````````````````70(``!(`
M````````````````````````.P(``!(`````````````````````````$0``
M`"``````````````````````````9`(``!(`````````````````````````
M\`(``!(`````````````````````````M````!(`````````````````````
M````>0(``!(`````````````````````````@P$``!(`````````````````
M````````V`(``!(`````````````````````````T`(``!(`````````````
M````````````A````!(`````````````````````````L0,``!(`````````
M````````````````#`$``!(`````````````````````````G`(``!(`````
M````````````````````C@(``!(`````````````````````````3`(``!(`
M````````````````````````Z0(``!(`````````````````````````!@,`
M`!(`````````````````````````9P$``!(`````````````````````````
M-0$``!(`````````````````````````P@```!(`````````````````````
M````L0$``!(`````````````````````````%`(``!(`````````````````
M````````0P(``!(`````````````````````````)`(``!(`````````````
M````````````G@$``!(`````````````````````````<@(``!(`````````
M````````````````X@$``!(`````````````````````````2@,``!(`````
M````````````````````0P,``!(`````````````````````````0P$``!(`
M````````````````````````^0(``!(`````````````````````````+0``
M`"``````````````````````````L`(``!(`````````````````````````
M9````!(```````````````````````````(``!(`````````````````````
M````J@$``!(`````````````````````````DP```!(`````````````````
M````````GP```!(`````````````````````````7`$``!(`````````````
M````````````(@$``!(`````````````````````````5@```!(`````````
M````````````````%@$``!(`````````````````````````MP(``!(`````
M````````````````````DP$``!(`````````````````````````\````!(`
M````````````````````````:@(``!(`````````````````````````VP$`
M`!(`````````````````````````-`,``!(`````````````````````````
M#0,``!(`````````````````````````=0$``!(`````````````````````
M````<P```!(`````````````````````````/`,``!(`````````````````
M````````AP(``!(`````````````````````````U````!(`````````````
M````````````4P$``!(`````````````````````````Q0(``!(`````````
M````````````````-@(``!(`````````````````````````^`$``!(`````
M````````````````````H@(``!(`````````````````````````/````"``
M````````````````````````@`(``!(`````````````````````````%P,`
M`"(`````````````````````````E0(``!(`````````````````````````
M)@,``!(`````````````````````````N@,``!(`#@"`5@```````'``````
M````B`,``!(`#P"$5P``````````````````WP,``!(`#@`P1@```````%0,
M````````5P,``!(`#@`P'@```````"T"````````C@,``!(`#@!P/P``````
M``4`````````300``!(`#@"`/P```````!H"````````1P0``!(`"P!`&@``
M````````````````>@0``!(`#@"04@```````.T#````````;0,``!``&0`@
ML"``````````````````Q@,``!(`#@"@00```````"H`````````^0,``!$`
M$`"05P````````0`````````O`$``!$`%0"@JR```````!,`````````>0,`
M`!``&0"HP"``````````````````100``!(`#@`@/@```````#``````````
M6@0``!(`#@!010```````-P`````````;`0``!(`#@"@1````````'0`````
M````[`,``!``&```L"``````````````````TP,``!(`#@#000```````.P`
M````````7`,``!$`&0!(L"````````@`````````9@,``!``&``@L"``````
M````````````70,``"$`&0!(L"````````@`````````+@0``!$`&``8L"``
M``````@`````````X@(``!$`&0!@L"````````@`````````?@,``!(`#@"`
M5P````````(`````````'@0``!(`#@`05P```````&4`````````\@,``!(`
M#@!@(````````"L`````````[@,``"``&```L"```````````````````0$`
M`!$`&0`@L"````````0`````````7@,``"$`&0!(L"````````@`````````
MGP,``!(`#@`@10```````"0`````````"`0``!(`#@"@/@```````,$`````
M````XP```!$`&0!`L"````````$`````````.`0``!(`#@#`0@```````-L!
M`````````&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?
M97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L
M;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO
M8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R
M;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS
M=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN
M:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ
M90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`
M7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D
M:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S
M960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P
M87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S
M971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"
M3T]4`$=,24)#7S(N,BXU`$=,24)#7S(N,30`1TQ)0D-?,BXS+C0`1TQ)0D-?
M,BXS+C(`1TQ)0D-?,BXT``````(``P`"``(````"``(````"`````@`"````
M`@````(``@`$``(``@````````````,``@`%`````@`#``(``@````8````'
M`````P`"``````````````````8```````(``P`"``(```````(``@``````
M`@`"``,`!@````(``@`"``8``0`!``$``0`!``$``0`!``$``0`!`````0`!
M``$``0`!``$``@`!``(``0`"``$``0`!``$````"``$``0````$```````$`
M`0#+`0``$````"````!U&FD)```#`)`$`````````0`%`!H"```0````````
M`)21E@8```<`G`0``!````!T&6D)```&`*<$```0````<AEI"0``!0"S!```
M$````!1I:0T```0`OP0``!````!U&FD)```"`)`$````````D*L@```````(
M`````````&`A````````F*L@```````(`````````"`A````````"+`@````
M```(``````````BP(```````&+`@```````(`````````+!:````````N*\@
M```````&````!0``````````````P*\@```````&````"@``````````````
MR*\@```````&````'P``````````````T*\@```````&````(P``````````
M````V*\@```````&````*P``````````````X*\@```````&````-@``````
M````````Z*\@```````&````/P``````````````\*\@```````&````00``
M````````````H*L@```````%````3P``````````````(+`@```````%````
M7P``````````````0+`@```````%````8P``````````````2+`@```````%
M````5@``````````````8+`@```````%````6@``````````````X*T@````
M```'`````0``````````````Z*T@```````'`````@``````````````\*T@
M```````'`````P``````````````^*T@```````'````!```````````````
M`*X@```````'````!@``````````````"*X@```````'````!P``````````
M````$*X@```````'````"```````````````&*X@```````'````"0``````
M````````(*X@```````'````"P``````````````**X@```````'````#```
M````````````,*X@```````'````#0``````````````.*X@```````'````
M#@``````````````0*X@```````'````#P``````````````2*X@```````'
M````$```````````````4*X@```````'````$0``````````````6*X@````
M```'````$@``````````````8*X@```````'````$P``````````````:*X@
M```````'````%```````````````<*X@```````'````%0``````````````
M>*X@```````'````%@``````````````@*X@```````'````%P``````````
M````B*X@```````'````&```````````````D*X@```````'````&0``````
M````````F*X@```````'````&@``````````````H*X@```````'````&P``
M````````````J*X@```````'````'```````````````L*X@```````'````
M'0``````````````N*X@```````'````'@``````````````P*X@```````'
M````(```````````````R*X@```````'````(0``````````````T*X@````
M```'````(@``````````````V*X@```````'````)```````````````X*X@
M```````'````)0``````````````Z*X@```````'````)@``````````````
M\*X@```````'````)P``````````````^*X@```````'````*```````````
M`````*\@```````'````*0``````````````"*\@```````'````*@``````
M````````$*\@```````'````+```````````````&*\@```````'````+0``
M````````````(*\@```````'````+@``````````````**\@```````'````
M+P``````````````,*\@```````'````,```````````````.*\@```````'
M````,0``````````````0*\@```````'````,@``````````````2*\@````
M```'````,P``````````````4*\@```````'````-```````````````6*\@
M```````'````-0``````````````8*\@```````'````-P``````````````
M:*\@```````'````.```````````````<*\@```````'````.0``````````
M````>*\@```````'````.@``````````````@*\@```````'````.P``````
M````````B*\@```````'````/```````````````D*\@```````'````/0``
M````````````F*\@```````'````/@``````````````H*\@```````'````
M0```````````````J*\@```````'````0@``````````````L*\@```````'
M````0P``````````````2(/L"$B+!865(`!(A<!T`O_02(/$",,`````````
M``#_-6J3(`#_)6R3(``/'T``_R5JDR``:`````#IX/____\E8I,@`&@!````
MZ=#_____)5J3(`!H`@```.G`_____R52DR``:`,```#IL/____\E2I,@`&@$
M````Z:#_____)4*3(`!H!0```.F0_____R4ZDR``:`8```#I@/____\E,I,@
M`&@'````Z7#_____)2J3(`!H"````.E@_____R4BDR``:`D```#I4/____\E
M&I,@`&@*````Z4#_____)1*3(`!H"P```.DP_____R4*DR``:`P```#I(/__
M__\E`I,@`&@-````Z1#_____)?J2(`!H#@```.D`_____R7RDB``:`\```#I
M\/[___\EZI(@`&@0````Z>#^____)>*2(`!H$0```.G0_O___R7:DB``:!(`
M``#IP/[___\ETI(@`&@3````Z;#^____)<J2(`!H%````.F@_O___R7"DB``
M:!4```#ID/[___\ENI(@`&@6````Z8#^____);*2(`!H%P```.EP_O___R6J
MDB``:!@```#I8/[___\EHI(@`&@9````Z5#^____)9J2(`!H&@```.E`_O__
M_R62DB``:!L```#I,/[___\EBI(@`&@<````Z2#^____)8*2(`!H'0```.D0
M_O___R5ZDB``:!X```#I`/[___\E<I(@`&@?````Z?#]____)6J2(`!H(```
M`.G@_?___R5BDB``:"$```#IT/W___\E6I(@`&@B````Z<#]____)5*2(`!H
M(P```.FP_?___R5*DB``:"0```#IH/W___\E0I(@`&@E````Z9#]____)3J2
M(`!H)@```.F`_?___R4RDB``:"<```#I</W___\E*I(@`&@H````Z6#]____
M)2*2(`!H*0```.E0_?___R4:DB``:"H```#I0/W___\E$I(@`&@K````Z3#]
M____)0J2(`!H+````.D@_?___R4"DB``:"T```#I$/W___\E^I$@`&@N````
MZ0#]____)?*1(`!H+P```.GP_/___R7JD2``:#````#IX/S___\EXI$@`&@Q
M````Z=#\____)=J1(`!H,@```.G`_/___R72D2``:#,```#IL/S___\ERI$@
M`&@T````Z:#\____)<*1(`!H-0```.F0_/___R6ZD2``:#8```#I@/S___\E
MLI$@`&@W````Z7#\____):J1(`!H.````.E@_/___R6BD2``:#D```#I4/S_
M__\EFI$@`&@Z````Z4#\____)<J1(`!FD```````````55-(@^PXB7PD'$B)
M="002(U\)!Q(B50D"$B-="002(U4)`AD2(L$)2@```!(B40D*#'`Z`C^__](
MBS5ID2``2(L]:I$@`$B)\NAR.```@#V[D2```'4OZ#3]__](A<!(B04*HB``
M#X2W`0``2(G'Z&S\__^+/7:1(`#HT?W__\:`T0@```"+/621(`#HO_W__X"(
MJ@0```*+/5*1(`#HK?W__X"(J@0```&+1"0<C7@%2+C_________'TAC_T@Y
MQP^'(@$``$C!YP-(C1UB.@``Z/G\__](BWPD$$B)!76A(`#'!7.A(``$````
M2(L72(E8"$B-'3PZ``!(B5@82(D02(L5WY`@`$B)4!"+5"0<@_H!1(U*!'XM
M1(U*!$B#QPB^!0```&8/'X0``````$R+!TACSH/&`4B#QPA!.?%,B43(^'7I
M2(L](J$@`$UCR4B--<@>``"#P@-%,<!*QT3(^`````!(B<'H8?W__X7`B<-T
M9$B+/?2@(`!(C6PD).C:^___2(T]=S@``#'`2(GNZ+D7``!(A<!T*DB+/<V@
M(`#H6/O__^CS_/__B=A(BUPD*&1(,QPE*````'5?2(/$.%M=PTB+/9N@(`!(
MA?]T+.AY-@``Z\-(BSV0H"``Z(O]__^)P^N,2(TU@(L@`$B-/;\W```QP.B"
M_/__2(T]M#<``$B)[NA#%P``2(7`2(G'2(D%3J`@`'2`Z[3H#?O__[\!````
MZ&/]__\/'P`Q[4F)T5Y(B>)(@^3P4%1,C04*-P``2(T-DS8``$B-/:S]____
M%3Z/(`#T#Q]$``!(C3V)CR``54B-!8&/(`!(.?A(B>5T&4B+!0J/(`!(A<!T
M#5W_X&8N#Q^$``````!=PP\?0`!F+@\?A```````2(T]28\@`$B--4*/(`!5
M2"G^2(GE2,'^`TB)\$C!Z#](`<9(T?YT&$B+!>F.(`!(A<!T#%W_X&8/'X0`
M`````%W##Q]``&8N#Q^$``````"`/4&/(```=2](@SV_CB```%5(B>5T#$B+
M/<J.(`#HW?S__^A(____Q@49CR```5W##Q^``````//#9@\?1```54B)Y5WI
M9O___V8/'T0``$%7059,C4\X055!5$4QP%532('LF`(``&1(BP0E*````$B)
MA"2(`@``,<!(B>%FD$.+!`%+BS0!#\A(B?*)P$C!ZB!*B01!2(GP2,'N.$C!
MZ"@E`/\``$@)\$B)UDC!X@A(P>88@>(``/\`B?9("?!("=!*B41!"$F#P`A)
M@_A`=:Y(C;$``@``#Q^``````$B+06A(,T%`2(/!"$@S00A(,T'X2(T4`$C!
MZ!]("="#X/](B4%X2#GQ==5,BQ=(BU\02(MW($B+;QA,BT\(3(G03(G22,'J
M&TC!X`5("=`#!"2-E#"9>8):2(G82(MT)`A(,>A,(<A(,>A(C;0UF7F"6D2-
M+`),B<I,B<A(P>@"2,'B'D@)PDB)V$V)Z(G12<'H&T@QR$PAT$@QV$@!\$R)
M[DC!Y@5,"<9$C20&3(G63(G02,'F'DC!Z`)("?!(BW0D$$V)XT@QPDG!ZQM!
MB<!,(>I(C;0SF7F"6D@QRD@!\DR)YDC!Y@5,"=Y$C1P63(GN2(M4)!A)P>T"
M2,'F'DP)[D@Q\$B-E!&9>8):3(G93"'@08GV3#'`2,'I&T@!T$R)VDC!X@5(
M"<I,B>%)P>P"1(TL`DC!X1Y(BU0D($P)X4B)\$@QR$R)[D&)S$PAV$F-E!"9
M>8):2,'N&TPQ\$@!T$R)ZDC!X@5("?)$C00"3(G:2(M$)"A)P>L"2,'B'DP)
MVDR)QD@QT4F-A`:9>8):2,'N&TPAZ4&)TTPQX4@!P4R)P$C!X`5("?!$C30(
M3(GH2(M,)#!)P>T"2,'@'DP)Z$R)]D@QPDF-C`R9>8):08G%3"'"3#':2`'*
M3(GQ2,'A!4C![AM("?%,B<9)P>@"1(TD$4C!YAY(BU0D.$P)QD@Q\$R)X4&)
M\$PA\$F-E!.9>8):2,'I&TPQZ$@!T$R)XDC!X@5("<I,B?%)P>X"1(T<`DC!
MX1Y(BU0D0$P)\4B)\$@QR$R)WD&)SDPAX$F-E!69>8):2,'N&TPQP$@!T$R)
MVDC!X@5("?)$C2P"3(GB2(M$)$A)P>P"2,'B'DP)XDR)[D@QT4F-A`"9>8):
M2,'N&TPAV4&)U$PQ\4@!P4R)Z$C!X`5("?!$C00(3(G82(M,)%!)P>L"2,'@
M'DP)V$R)QD@QPDF-C`Z9>8):2,'N&TPAZD&)PTPQXD@!RDR)P4C!X05("?%,
MB>Y)P>T"1(TT$4C!YAY(BU0D6$P)[D@Q\$R)\4&)]4PAP$F-E!29>8):2,'I
M&TPQV$@!T$R)\DC!X@5("<I,B<%)P>@"1(TD`DC!X1Y(BU0D8$P)P4B)\$@Q
MR$R)YD&)R$F-E!.9>8):3"'P2,'N&TPQZ$@!T$R)XDC!X@5("?)$C1P"3(GR
M2(M$)&A(P>(>2<'N`DP)\DR)WD@QT4F-A`69>8):2,'N&TPAX4&)UDPQP4@!
MP4R)V$C!X`5("?!$C2P(3(G@2(M,)'!)P>P"2,'@'DP)X$R)[D@QPDF-C`B9
M>8):2,'N&TPAVD&)Q$PQ\D@!RDR)Z4C!X05("?%,B=Y)P>L"1(T$$4C!YAY(
MBU0D>$P)WD@Q\$R)P4&)\TPAZ$F-E!:9>8):2,'I&TPQX$@!T$R)PDC!X@5(
M"<I,B>E)P>T"1(TT`DC!X1Y(BY0D@````$P)Z4B)\$@QR$R)]D&)S4PAP$F-
ME!29>8):2,'N&TPQV$@!T$R)\DC!X@5("?)$C20"3(G"2(N$)(@```!)P>@"
M2,'B'DP)PDR)YD@QT4F-A`.9>8):2,'N&TPA\4&)T$PQZ4@!P4R)X$C!X`5(
M"?!(B[0DD````$2-'`A,B?!)P>X"2,'@'DP)\$F-M#69>8):38G=2#'"2<'M
M&XG!3"'B3#'"2`'R3(G>2,'F!4P)[HGV2`'R3(GF2<'L`DC!YAY!B=5,">9,
MBZ0DF````$@Q\$PAV$^-A""9>8):2#'(38GL2<'L&TP!P$V)Z$G!X`5-">!%
MB<!,`<!-B=A)P>L"2<'@'D&)Q$T)V$F)\XGV33'#2`.T)*@```!$,=I,BYPD
MH````$J-C!FAZ]EN38GC2<'K&T@!T4R)XDC!X@5,"=J)TD@!T4R)ZDG![0)(
MP>(>08G+3`GJ38G%18G`23'53`.$)+````!$,>A-B=U(C;0&H>O9;DR)V$G!
M[1M(P>`%3`GHB<!(`?!,B>9)P>P"2,'F'D&)Q4P)YDF)U(G223'T1#'A38GL
M2`.4)+@```!-C80(H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=E)P>L"2,'A
M'D6)Q$P)V4F)\XGV23'+2`.T),````!$,=A-B>-(C90"H>O9;DR)X$G!ZQM(
MP>`%3`G8B<!(`<),B>A)P>T"2,'@'D&)TTP)Z$F)S8G)23'%2`.,),@```!%
M,>A-B=U.C80&H>O9;DR)WDG![1M(P>8%3`GNB?9,`<9-B>!)P>P"2<'@'D&)
M]4T)X$F)Q(G`33'$1#'B38GL2(V,$:'KV6Y,B>I(P>(%2<'L&T@#A"30````
M3`GBB=)(`=%,B=I)P>L"2,'B'D&)S$P)VDV)PT6)P$DQTTP#A"38````1#'>
M38GC2(VT,*'KV6Y,B>!)P>L;2,'@!4P)V(G`2`'P3(GN2<'M`DC!YAY!B<-,
M">Y)B=6)TDDQ]4@#E"3@````1#'I38G=38V$"*'KV6Y,B=E)P>T;2,'A!4P)
MZ8G)20'(3(GA2<'L`DC!X1Y%B<5,">%)B?2)]DDQS$0QX$V)[$B-E`*AZ]EN
M3(GH2<'L&TC!X`5,">")P$@!PDR)V$@#M"3H````2<'K`DC!X!Y!B=1,"=A)
MB<N)R4DQPT@#C"3P````13'838GC3HV$!J'KV6Y,B>9)P>L;2,'F!4P)WHGV
M3`'&38GH2<'M`DG!X!Y!B?--">A)B<6)P$TQQ4@#A"3X````1#'J38G=2(V,
M$:'KV6Y,B=I)P>T;2,'B!4P)ZHG22`'13(GB2<'L`DC!XAY!B<U,">)-B<1%
MB<!),=1$,>9-B>Q(C;0PH>O9;DR)Z$G![!M(P>`%3`G@B<!(`?!,B=Y(P>8>
M2<'K`DP#A"0``0``3`G>28G308G$23'SB=)(`Y0D"`$``$0QV4V)XTV-A`BA
MZ]EN3(GA2<'K&TC!X05,"=F)R4D!R$R)Z4G![0)(P>$>18G#3`GI28GUB?9)
M,<U(`[0D$`$``$0QZ$V)W4B-E`*AZ]EN3(G82<'M&TC!X`5,">B)P$@!PDR)
MX$G![`)(P>`>08G53`G@28G,B<E),<1%,>!-B>Q.C80&H>O9;DR)[DG![!M(
MP>8%3`GFB?9,`<9-B=A)P>L"2<'@'D&)]$T)V$@#C"08`0``28G#33'#B<!(
M`X0D(`$``$0QVDV)XTG!ZQM(C8P1H>O9;DR)XDC!X@5,"=J)TD@!T4R)ZDG!
M[0)(P>(>08G+3`GJ38G%18G`23'53`.$)"@!``!$,>Y-B=U(C;0PH>O9;DR)
MV$G![1M(P>`%3`GHB<!(`?!,B>9)P>P"2,'F'D&)Q4P)YDF)U(G223'T2`.4
M)#`!``!$,>%-B>Q-C80(H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=E)P>L"
M2,'A'D6)Q$P)V4F)\XGV23'+1#'838GC2`.T)#@!``!(C90"H>O9;DR)X$G!
MZQM(P>`%3`G81(T<$$R)Z$G![0)(P>`>3`GH28G-B<E),<6)PD4QZ$V)W4Z-
MA`:AZ]EN3(G>2<'M&TC!Y@5,">Y,BZPD0`$``$:--`9-B>!)P>P"2<'@'DT)
MX$P)P$2)QDF)Q$B)T$@A\$TAW$D)Q+C<O!N/20'%3`'I38GU20',3(GQ2<'M
M&TC!X05,">E)B?5!`<Q,B=E)P>L"2,'A'DP)V4&)RTD)R$TA\$TAW4T)Z$R+
MK"1(`0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,">I&C2P"3(GR2<'N`DC!
MXAY,"?)-B=Y!B=!("=%-(<9,(>%,"?%,B[0D4`$``$D!QDP!]DV)[D@!\4R)
M[DG![AM(P>8%3`GV1(TT#DR)YDG![`)(P>8>3`GF38G$B?%("?))(<Q,(>I,
M">),BZ0D6`$``$D!Q$T!XTV)]$P!VDV)\TG!XP5)P>P;30GC18TD$TV)ZTG!
M[0))P>,>30GK28G-1(G:3`G>22'53"'V3`GN3(NL)&`!``!)`<5-`>A-B>5,
M`<9-B>!)P>T;2<'@!4T)Z$6-+#!-B?!)P>X"2<'@'DT)\$F)UD2)QDT)PTDA
M]DTAXTT)\TR+M"1H`0``20'&3`'Q38GN20'+3(GI2<'N&TC!X05,"?%&C309
M3(GA2<'L`DC!X1Y,">%)B?1!B<M)"<A-(>A-(=Q-">!,BZ0D<`$``$D!Q$P!
MXDV)]$D!T$R)\DG![!M(P>(%3`GB1HTD`DR)ZDG![0)(P>(>3`GJ38G=08G0
M2`G132'%3"'Q3`GI3(NL)'@!``!)`<5,`>Y-B>5(`?%,B>9)P>T;2,'F!4P)
M[D2-+`Y,B?9)P>X"2,'F'DP)]DV)QHGQ2`GR22'.3"'B3`GR3(NT)(`!``!)
M`<9-`?--B>Y,`=I-B>M)P>,%2<'N&TT)\T6--!--B>-)P>P"2<'C'DT)XTF)
MS$2)VDP)WDDAU$PA[DP)YDR+I"2(`0``20'$30'@38GT3`'&38GP2<'L&TG!
MX`5-">!%C20P38GH2<'M`DG!X!Y-">A)B=5$B<9-"<-)(?5-(?--">M,BZPD
MD`$``$D!Q4P!Z4V)Y4D!RTR)X4G![1M(P>$%3`GI1HTL&4R)\4G![@)(P>$>
M3`GQ28GV20G(08G+32'>32'@30GP3(NT))@!``!)`<9,`?)-B>Y)`=!,B>I)
MP>X;2,'B!4P)\D:--`),B>))P>P"2,'B'DP)XDV)W$&)T$@)T4TAQ$PAZ4P)
MX4R+I"2@`0``20'$3`'F38GT2`'Q3(GV2<'L&TC!Y@5,">9$C20.3(GN2<'M
M`DC!YAY,">Y-B<6)\4@)\DDAS4PA\DP)ZDR+K"2H`0``20'%30'K38GE3`':
M38GC2<'M&TG!XP5-">M%C2P338GS2<'N`DG!XQY-"?-)B<Y$B=I,"=Y)(=9,
M(>9,"?9,B[0DL`$``$D!QDT!\$V)[DP!QDV)Z$G![AM)P>`%30GP18TT,$V)
MX$G![`))P>`>30G@28G41(G&30G#22'T32'K30GC3(ND)+@!``!)`<1,`>%-
MB?1)`<M,B?%)P>P;2,'A!4P)X4:-)!E,B>E)P>T"2,'A'DP)Z4F)]4&)RTD)
MR$TA\$TAW4T)Z$R+K"3``0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,">I&
MC2P"3(GR2<'N`DC!XAY-B=A,"?)!B=9("=%-(?!,(>%,"<%,BX0DR`$``$D!
MP$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$#DR)YDG![`)(P>8>3(GQ3`GF
M08GT2`GR3"'A3"'J2`G*2(N,)-`!``!(`<%)`<M,B<%(`X0DV`$``$P!VDV)
MPTC!X05)P>L;3`G9B<E,`?!(`<I,B>E)P>T"2,'A'D&)TTP)Z4V)Y4&)ST@)
MSDTA_4PAQDP)[DV)W4@!\$R)WDG![1M(P>8%3`GNB?9(`?!,B<9)P>@"2,'F
M'D&)Q4D)\+[6P6+*3#'!,<I(BXPDX`$``$@!\4D!S$R)Z4P!XDV)[$C!X05)
MP>P;3`GAB<E(`<I,B=E(P>$>2<'K`D&)U$D)RTR)P4V)YDPQV4G![AM%B<`Q
MR$B+C"3H`0``2`'Q20'/2HT,.$R)X$C!X`5,"?")P$R--`%,B>A)P>T"2,'@
M'DR)V46)VTD)Q4B+A"3P`0``18GW3#'I,<I,B?E(`?!(P>D;3`'`2`'"3(GX
M2,'@!4@)R$B+C"3X`0``B<!(`<),B>!)P>P"2,'@'D@!\4&)T$P)X$P!V4V)
MZTDQPTV)Q$6)[44QWDG![!M.C1PQ3(G!2,'A!4P)X8G)20'+3(GY2<'O`DC!
MX1Y%B=Q)"<](BXPD``(``$@!\4P!Z4F)Q8G`33']1#'J3(TL$4R)XDR)X4C!
MZ1M(P>(%2`G*3(G!2<'H`HG22,'A'DD!U4B+E"0(`@``3`G!38GX18GN18G_
M23'(2`'R13'#2`'03(GR3HT$&$R)\$C!ZAM(P>`%2`G02(G*B<F)P$D!P$R)
MX$G![`)(P>`>18G#20G$2(N$)!`"``!,,>)!,=5,B=I(`?!,`?A)`<5,B=A(
MP>`%2,'J&T@)T$R)\DG![@*)P$C!XAY)`<5(BX0D&`(``$P)\D6)[T@!\$@!
MR$R)X46)Y$@QT4$QR$R)^4D!P$R)^$C!Z1M(P>`%2`G(B<!)`<!,B=A)P>L"
M2,'@'D6)QDD)PTB+A"0@`@``3(GQ2,'I&T@!\$P!X$F)U(G233'<13'E3HTD
M*$R)\$C!X`5("<A(BXPD*`(``(G`20'$3(GX2<'O`D@!\4C!X!Y%B>5,"?A(
M`<I,B=E(,<%%B=M!,<A,B>E)`=!,B>I(P>D;2,'B!4@)RHG220'03(GR2<'N
M`DC!XAY%B<=)"=9(BY0D,`(``$R)^4C!Z1M(`?),`=I)B<.)P$TQ\T4QW$Z-
M'"),B?I(P>(%2`G*3(GI2<'M`HG22,'A'DD!TTB+E"0X`@``3`GI18G<2`'R
M2`'03(GR18GV2#'*03'03(GB20'`3(G@2,'J&TC!X`5("=!(B<J)R8G`20'`
M3(GX2<'O`DC!X!Y%B<5)"<=(BX0D0`(``$@!\$PQ^DP!\$$QTTR)ZDD!PTR)
MZ$C!ZAM(P>`%2`G03(GB2<'L`HG`2,'B'DD!PTB+A"1(`@``3`GB18G>28G4
M2`'P2`'(3(GY18G_2#'1B=)!,<A*C0P`3(GP38GP2<'H&TC!X`5,"<")P$@!
MP4R)Z$G![0)(P>`>08G(20G%2(N$)%`"``!-,>Q%,>--B<1(`?!)P>P;3`'X
M20'#3(G`2,'@!4P)X(G`20'#3(GP2,'@'DG![@)%B=Q,"?!,B[0D6`(``$D!
M]DD!UDR)ZD6)[4@QPC'128T4#DR)X4V)YDG![AM(P>$%3`GQB<E(`<I,B<%)
MP>@"2,'A'D&)UDD)R$B+C"1@`@``2`'Q3`'I28G%B<!-,<5%,>M-B?5)`<M,
MB?%)P>T;2,'A!4P)Z8G)20'+3(GA2<'L`DC!X1Y%B=U)"<Q(BXPD:`(``$@!
M\4@!R$R)P46)P$PQX3'*2(T,$$R)Z$R)ZDC!ZAM(P>`%2`G03(GR2<'N`DC!
MXAZ)P$D)UDB+E"1P`@``2`'!B<A(`?),`<)-B>!-,?!%,<-)B<!,`=I)B<-)
MP>`%2<'K&TT)V$F)PTC!Z`))P>,>00'03(GJ20G#2(N$)'@"``!(P>(>2<'M
M`D$!VTD)U42)XDR)7Q!(`?!$`>U(`<),B?!(B6\83#'H,<%(C00*3(G"3(G!
M2,'B!4C!Z1M%`<A("<I,B4<(`=!!`<)$`W<@2(N$)(@"``!D2#,$)2@```!,
MB1=,B7<@=1)(@<28`@``6UU!7$%=05Y!7\/HXN/__V:005=!5D%505154TB#
M[`A(A?\/A+$```!,BSVJ>"``387_#X2A````#[8'A,!T!#P]=5Y%,>1)BQ](
MA=MT.4F)]4F)_DUCY$R)_0\?@`````!,B>),B?9(B=_HPN+__X7`=0="@#PC
M/71'2(/%"$B+70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M28/$`4$/M@0DA,!T!#P]=>]!*?SKC`\?@`````!,*?U*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%532(G]2(/L&&1(BP0E*````$B)1"0(,<!(C5PD
M!&:0,<!(B=Y(B>_H`____TB%P'0V2&-4)`1(BP6Z=R``2(T$T$B+4`A(A=)(
MB1!TTF:02(/`"$B+4`A(A=)(B1!U\.N^9@\?1```2(M$)`AD2#,$)2@```!U
M!TB#Q!A;7</HC.+__V:09BX/'X0``````$%7059!54%455-(B?-(B?U(@^PH
M9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'#2(G?Z#GB__](C70D%$F)Q$B)
M[S'`Z%?^__](A<`/A`X!``!(B<=)B<7H$^+__TPYX`^#X@```$QC="042<'F
M`P^V10"$P`^$K0$``#P]#X2E`0``2(GHZPT/'X0``````(#Z/70+2(/``0^V
M$(32=?!(*>A(F$P#-;QV(`!*C7P@`NCZXO__2(7`28D&#X1[`0``2&-4)!1(
MBP6:=B``2(U-`4B+%-`/MD4`/#V(`G0FA,!U$.L@9BX/'X0``````#P]=!)(
M@\$!#[9!_TB#P@&$P(@"=>K&`CTQP`\?1```#[8,`XA,`@%(@\`!A,EU\#'`
M2(MT)!AD2#,T)2@````/A1$!``!(@\0H6UU!7$%=05Y!7\,/'P!(@\,!#[9#
M_TF#Q0&$P$&(1?]U[.O"9I!,BST!=B``28,_``^$OP```$R)^#'2ZPL/'X0`
M`````$2)ZDB#P`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%_X4@`(7`=5M(B??'
M!>Z%(``!````Z/GA__](A<`/A'T```!-8\5,B?Y(B<=.C33%`````$R)1"0(
M3(GRZ(+B__],BT0D"$B)P4B)!7MU(`!*QT3!"`````!$B6PD%.EO_O__3(G_
MZ#CB__](A<!(B<%(B053=2``="9-8\5.C33%`````.O)#Q]``#'`Z7;^__^0
MOA````!%,>WI7O___[C_____Z=O^___H-.#__P\?0`!!5T%6055!5%532('L
MN````&1(BP0E*````$B)A"2H````,<!(A?]T"(`_`$F)_G4O2(N$)*@```!D
M2#,$)2@````/A20!``!(@<2X````6UU!7$%=05Y!7\-F#Q]$``#H:]___TB%
MP$B)PW3$2(U$)!!(C2WL&P``3(TEY!L``$R-/>`;``!(B00D2(G?Z(WA__](
MA<`/A+0```!,C4@3N0(```!(B>],B<[SIG3<N0,```!,B<Y,B>?SIG3-3(GW
M3(E,)`CH5=___TR+3"0(28G%3(G/Z$7?__]!C7P%`DAC_^AXX/__3(M,)`A)
MB<5(B<=-B?!,B?E(Q\+_____O@$````QP.C4X?__2(L4)+\!````3(GNZ*/>
M__^#^/],B>]T$(M$)"@E`/```#T`0```=##H)M[__TR)[^C^W?__Z43___]F
M#Q^$``````!(B=_H6-___TR)]^BPWO__Z<S^___HEO[__^O.Z+_>__\/'T0`
M`&8N#Q^$``````!32(G[BSUF<R``Z,'?__](C9```@``2(G>OP$```#HW>#_
M_X7`=`DQP%O##Q]$``"+/3IS(`#HE=___XN`&`(``"4`\```/0!```!T'8L]
M'7,@`.AXW___BX`8`@``)0#P```]`*```'6]2(G?O@(```#H2>#__X7`#Y3`
M#[;`6\,/'T0``&8N#Q^$``````!!5D%528GV051528G\4TB-/4@:``"Z_P\`
M`$B![!`0``!(B>-(B=YD2(L$)2@```!(B80D"!```#'`Z$'=__^%P`^.B0``
M`(U0_T2++8]R(`!(8^J`/"P`=%9(8^A(B>J^+P```$B)W^ACWO__2(7`=$9$
MB>_HQM[__TB)Z4B)VDR)YDB)Q^C%W___2(N$)`@0``!D2#,$)2@```!U.TB!
MQ!`0``!;74%<05U!7L-FD(72=:D/'T``1(GOZ(#>__],B?),B>9(B<?HDMW_
M_^N[1(LM"7(@`.O?Z$+=__]FD$B#[`B+/?9Q(`#H4=[__TB+%8IQ(`!(C0U;
M&P``2(TU:!D``$B)QTB#Q`CI<-[__TB#[`B+/<9Q(`#H(=[__TB)Q^BY____
MBSVS<2``Z`[>__],C07(&@``2(T5$!0``$B--4$9``!%,<E(B<=(@\0(3(G!
MZ7?>__\/'X``````55-(@>PH(```9$B+!"4H````2(F$)!@@```QP$B)XTB-
MK"00$```Z!3<__],C0W5&```2(T-`QD``$&)P+H!$```O@$```!(B=\QP.@?
MW___N@`0``!(B>Y(B=_HO]O__X7`>%.->`%(B<-(8__H?=W__TB%P$B)P708
M2&/;2(GN2(G'2(G:Z#3=__](B<'&!!@`2(N4)!@@``!D2#,4)2@```!(B<AU
M$TB!Q"@@``!;7<,/'T0``#')Z]?H_]O__P\?1```9BX/'X0``````.DK____
MD&8N#Q^$``````!!5T%6055!5$F)]%532(G[2(T]4A@``$B!["@0``!D2(L$
M)2@```!(B80D&!```#'`2(UT)`SHQ??__[XO````2(G?2(G%Z+7;__](A<!T
M0$B-/1L8``!(B=XQP.C_^/__2(G82(N,)!@0``!D2#,,)2@````/A9H!``!(
M@<0H$```6UU!7$%=05Y!7\,/'P!(B=_H.-O__TB-->`7``!,B>=!B<7H5MW_
M_TB%P$F)QW2>08/%`4&`/P!,C60D$$R--;L7```/A.(````/'T``2(7M=!-,
MB?Y(B>_HT-O__X7`#X2B````3(G_Z.#:__^)PDB808!\!_\O=1</'T``@^H!
M2&/"08!\!_\O0<8$!P!T[40!ZH'Z_P\```^/+O___TB#[`A(C0U*&```38GQ
M4TV)^+H`$```O@$```!,B><QP.A(W?__BSU2;R``Z*W;__](C9```@``3(GF
MOP$```#H"=K__X7`6EEU'8L]+6\@`.B(V___BX`8`@``)0#P```]`(```'1>
M2(TU[A8``#'_Z&C<__](A<!)B<</A*S^__]!@#\`#X4B____2(7M=!U(C3U;
M%@``N0(```!(B>[SIG3$9BX/'X0``````$R-/3X6``"Z`0```.DR____#Q^`
M`````+X!````3(GGZ/O;__^%P'612(T]<A8``$R)YNA8]___3(GGZ&#<___I
M3_[__^C&V?__9@\?1```#[872(GXA-)T'F8/'T0``$B#QP&`^B\/MA=(#T3'
MA-)U[O/##Q]``//#9@\?1```2(7_#X3/````55-(@^P(#[8O0(3M="E(B?OH
M8=G__TB-5`/_2#G3<A#K.P\?1```2(/J`4@YTW0W@#HO=/+K'4B#Q`A(C3UZ
M%0``6UWISMO__V8/'T0``(`Z+W0X2(/J`4@YTW+R2#G3=2H/'T0``$"`_2]T
MRDB#Q`A(C3VP%0``6UWIF-O__P\?A```````@#HO=0E(@^H!2#G3<O)(*=I(
MC4("2#T`$```=SM(C3W\;2``2(/"`;D`$```2(G>Z%O:__](C07D;2``2(/$
M"%M=PP\?1```2(T]YA0``.D\V___#Q]``#'`Z^`/'T``4TB-/3L5``!(@^Q`
M9$B+!"4H````2(E$)#@QP`^W!:T6``!(C5PD#/,/;P6`%@``#RE$)!!FB40D
M,#'`\P]O!7P6```/*40D(.A"]?__2(T]]Q0``#'`Z#3U__](C3WQ%```,<#H
M)O7__TB-/>P4```QP.@8]?__2(T]Y10``#'`Z`KU__](C3WG%```,<#H_/3_
M_TB-/8X4```QP.CN]/__2(T]UQ0``#'`Z.#T__](C3W3%```,<#HTO3__TB-
M/<\4```QP.C$]/__2(T]7Q0``#'`Z+;T__](C3V]%```,<!(B=[HU?/__TB%
MP'012(T]DQ0``$B)QC'`Z!_U__](C3VG%```,<!(B=[HKO/__TB%P'012(T]
MHQ0``$B)QC'`Z/CT__](C3V=%```,<!(B=[HA_/__TB%P'1"2(T]Y!,``$B)
MQC'`Z-'T__](C36B%```2(T]!Q0``#'`Z+ST__](BT0D.&1(,P0E*````'5B
M2(/$0%O#9@\?1```2(T]510``#'`2(G>Z"_S__](A<!U*DB-="0A2(T]2Q0`
M`+D*````\Z9UI$B-="0K2(T]R1,``#'`Z&+T___KCTB-/;D3``!(B<8QP.A/
M]/__Z7G____HQ=;__P\?1```2(/L&&1(BP0E*````$B)1"0(,<"+!59K(`"#
M^/]T&4B+?"0(9$@S/"4H````=4!(@\08PP\?0`!(C70D!$B-/5P3```QP.B5
M\O__2(G",<!(A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(D%`VL@`.NPZ$S6__]F
MD&8N#Q^$``````!(@^P(Z$?6__^)Q^CPU?__2(7`=`M(BP!(@\0(PP\?`#'`
MZ_1FD&8N#Q^$``````!!5%5(B?U32(T]7!,``$B#[!!D2(L$)2@```!(B40D
M"#'`2(UT)`3H!/+__TB%P$B)[G1\@#@`2(G#='1(B<?H;-C__TB%P'5U2(GO
MZ*_5__](B=])B<3HI-7__TF-?`0"Z-K6__](@^P(3(T-/A(``$B-#2\3``!3
M2,?"_____TB)QTF)Q$F)Z+X!````,<#H*]C__TB-/<X2``!,B>8QP.CJ\O__
M6%KK%&8/'T0``$B-/;,2```QP.C2\O__2(M$)`AD2#,$)2@```!U"4B#Q!!;
M74%<P^@TU?__#Q]``$%7059!54%428G]55-(C3VE$0``2('LB($``&1(BP0E
M*````$B)A"1X@0``,<!(C05Q$@``3(UD)"Q(QT0D0`````!(QX0DF```````
M``!(QT0D8`````!(B40D,$B-!0$1``!,B>9(B40D.$B-!=X1``!(B40D<$B-
M!<L1``!(B40D>$B-!2`2``!(B80D@````$B-!<T1``!(B80DB````$B-!0H2
M``!(B80DD````$B-!>(1``!(B40D4$B-!?,1``!(B40D6#'`Z(#P__](A<!T
M"8`X``^%4@(``#'`Z`O^__](A<!(B<,/A(\"``!(B=_H)]3__TB-?``!Z%W5
M__^`.P!)B<9T-TR-/:X1``!,B?4/'P!$#[8#2(GO,<!,B?E(Q\+_____O@$`
M``!(@\,!2(/%`NBCUO__@#L`==9(C5PD<$B-/0,1``#K$$B#PPA(BSM(A?\/
MA'@!```QP$R)YNCF[___2(7`2(G%=-Z`.`!TV4B)Q^@!]?__A<!TS4B)[^@U
MUO__2(7`28G'#X1!`0``9@\?A```````3(GZBPI(@\($C8'__O[^]]$AR"6`
M@("`=.F)P<'I$*F`@```#T3!2(U*`D@/1-&)P0#!3(GQ2(/:`TPI^HLQ2(/!
M!(V&__[^_O?6(?`E@("`@'3IB<;![A"I@(````]$QDB-<0)(#T3.B<9``,9(
M@]D#3"GQC9P*!`0``$ACVTB)W^@YU/__2(G%2(T%G1```$%63(T-EP\``$B-
M#800``!-B?A02,?"_____[X!````2(GO,<#HA=7__[[``0``2(GOZ!C2__^#
M^/]!6$%9=1+HVM'__T2+"$&#^1$/A=,(``"+/6=G(`#HPM/__TB-D``"``!(
MB>Z_`0```.C>U/__A<!!B<</A$,!``!)BTT`2(L]>&<@`$B-%?D0``!)B>B^
M`0```#'`,=OHX-3__^M^9@\?1```,>UF#Q]$``!(8\5(BUS$,$B%VW0[@#L`
M=#9(B=^#Q0'H@_/__X7`=-](B=_HM]3__TB%P$F)QP^%B_[__TACQ4B+7,0P
M2(7;=<MF#Q]$``!%,?_I</[__TB)QTB)!"3HY/O__TB+!"1(B<?H>-3__TB)
MPP\?1```2(N,)'B!``!D2#,,)2@```!(B=@/A>4(``!(@<2(@0``6UU!7$%=
M05Y!7\,/'T``2(T]$P\``#'M2(7_="9FD#'`3(GF@\4!Z+/M__](A<!T!8`X
M`'4I2&/%2(M\Q%!(A?]UW+\-````2(T=WPX``.B;TO__28G&Z3[]__\/'P!(
MB<?HZ-/__TB%P$B)PP^%#?W__^O!9BX/'X0``````(L]^F4@`.A5TO__BX`8
M`@``)0#P```]`$````^%G/[__XL]V64@`.@TTO__1(NP'`(``.@8T?__03G&
M#X5\_O__BSVY92``Z!32__^+@!@"```E_P$``#W``0``#X5;_O__2(G?Z`;2
M__](C3TT#@``2(G#3(GF,<#HXNS__TB%P`^$:0$``$B)Q^A!T___28M]`$B)
MQNC%]/__2(7`28G$#X1)`0``3(GGZ('0__^#^`-^/$ACT$B-/24.``"Y!0``
M`$F-=!3\\Z9U)(/X!`^$"P8``(/H!$B808!\!/\O#X3Z!0``9BX/'X0`````
M`#'`Z(GY__^%P'45,?9,B>?H"]+__X7`08G&#X7P````2(TU@0T``$B-/0(-
M``!,C27\#0``,<!,C2VS#```Z(WM___HB,___T%43(T-H`P``%!(C0VS#0``
M2,?"_____TF)Z+X!````2(G?,<#HCM+__UA:ZTUF+@\?A```````Z.O.__^#
M.!%U2^A!S___08/'`4B#[`A(C0U\#0``051!5TV)Z5!)B>A(Q\+_____O@$`
M``!(B=\QP.A!TO__2(/$(+[``0``2(G?Z-#.__^#^/]TJTB)[^B#SO__2(T]
M]0L``$B)WC'`Z.+L__](B=_H2OG__^EU_?__#Q]$``!-BV4`Z:[^__\/'X``
M````N@(```!(Q\;N____B<?HG='__TB-A"1P`0``N@8```!$B?=(B<9(B00D
MZ-'/__^`O"1P`0```'4.@+PD<0$``$,/A(D%```QTC'V1(GWZ%W1__^XB:O-
M[TR-K"2@````2,>$)*`````!(T5G2(F$)*@```!(+8O.$E=(QX0DN````'94
M,A!(B80DL````$@%\@08*TC'A"3(`````````$B)A"3`````28U%.$C'A"30
M`````````,>$)!@!````````2(E$)`@/'X0``````$B+-"2Z`(```$2)]^@?
MS___A<!)B<1!B<`/CG$!``!(B[PDR````$ECQ$B+E"30````C33'2#G^2(FT
M),@```!(@](`2,'H'4@!T$B)A"30````2&.$)!@!``"%P`^$'0$``$B+3"0(
M0;A`````2(LT)$$IP$4YQ$4/3L1(C3P!26/028G72(E4)!#HX,[__XN$)!@!
M``!$`?B#^$")A"08`0``#X56____18G@3(GO12GX3(M\)!!,`SPD1(E$)!SH
MNM/__T2+1"0<#Q]$``!!@_@_?GE!C4#`B40D','H!D&)Q(E$)!!)@\0!2<'D
M!DT!_`\?1```\T$/;P=,B>])@\=`#Q&$)-@```#S00]O1]`/$80DZ````/-!
M#V]'X`\1A"3X````\T$/;T?P#Q&$)`@!``#H1=/__TTY_'6XBT0D$$2+1"0<
MP>`&02G`2(M\)`A)8]"Y2````$R)_D2)1"00Z/?-__]$BT0D$$2)A"08`0``
MZ87^__\/'T0``$R+/"3I1____P\?@`````!$B??H2,W__TR+I"3(````3(NT
M)-````!,B>!(P>@#@^`_C5`!2)C&A`38````@(/Z.`^/@P(``+@X````,?8I
MT$ACTH/X"$F-5!4X#X/<`@``J`0/A88#``"%P'0+J`+&`@`/A8H#``!,B?!,
MB>]$B+0D$P$``$C!Z!A$B*0D%P$``$R-K"1``0``B(0D$`$``$R)\$C!Z!"(
MA"01`0``3(GP3(TUQ@D``$C!Z`B(A"02`0``3(G@2,'H&(B$)!0!``!,B>!(
MP>@0B(0D%0$``$R)X$4QY$C!Z`B(A"06`0``Z`G2__](BX0DH````$B)PHB$
M)",!``!(P>H81`^VPHB4)"`!``!(B<)(P>H0B)0D(0$``$B)PDB+A"2H````
M2,'J"(B4)"(!``!(B<*(A"0G`0``2,'J&(B4)"0!``!(B<)(P>H0B)0D)0$`
M`$B)PDB+A"2P````2,'J"(B4)"8!``!(B<*(A"0K`0``2,'J&(B4)"@!``!(
MB<)(P>H0B)0D*0$``$B)PDB+A"2X````2,'J"(B4)"H!``!(B<*(A"0O`0``
M2,'J&(B4)"P!``!(B<)(P>H0B)0D+0$``$B)PDB+A"3`````2,'J"(B4)"X!
M``!(B<*(A"0S`0``2,'J&(B4)#`!``!(B<)(P>H0B)0D,0$``$B)PDC!Z@B(
ME"0R`0``Z0P````/'P!&#[:$)"`!``!+C7QE`#'`3(GQ2,?"_____[X!````
M28/$`>A8S?__28/\%'722(T%?`@``,:$)&@!````4$%52(T--@@``$R-#2,'
M``"^`0```$F)Z$C'PO____](B=\QP.@9S?__65[IY_K__V:038MM"$V%[0^$
M`_K__TR)[^@[RO__2(/X`P^&\?G__TF-=`7\2(T]W0<``+D%````\Z9-#T3E
MZ=7Y__^X0````$ACRBG028U,#3AT#S'2B=:#P@$YPL8$,0!R\TR)[^@-T/__
M9@_OP`\1A"38````2<=%:`````!!#Q%%2$$/$458Z6/]__])BTT`2(L]SUX@
M`$B-%1`(``!)B>B^`0```#'`,=OH-\S__^G2]___B<%(QP(`````2,=$"O@`
M````2(U*"$B#X?A(*<H!T(/@^(/X"`^"$/W__X/@^#'2B=>#P@@YPDB)-#ER
M\^GY_/__@+PD<@$``$$/A6GZ__^`O"1S`0``0P^%6_K__X"\)'0!``!(#X5-
M^O__@+PD=0$``$4/A3_Z__^Z`@```$C'QL;___]$B??HE,O__TR+/"2Z*0``
M`$2)]TR)_NC0R?__2(T%Z@8``%!!5^EQ_O__D,<"`````,=$`OP`````Z7;\
M__\Q_V:)?`+^Z6K\___HW,C__V:09BX/'X0``````$%7059!54%455-(@^P8
MBSU\72``9$B+!"4H````2(E$)`@QP$R-;"0$Z,+)__^+/5Q=(`!(B</HM,G_
M_P^VD[@```!(C3U*!0``3(GNB)"Y````,<#HEN3__TB%P'0)@#@Q#X0(`P``
M,<#HP>___XL]&UT@`.AVR?__2(TU*@8``+D+````N@$```!(B<?H'<G__TB%
MP`^$Q````(,]76T@``%(BT`01(LUXEP@`$R+8"@/CJ\````Q[;L!````ZSH/
M'X``````28MW$$B+!25M(`!(8]-(BSS0Z,'(__^%P(L5&6T@``^%"`(``(/#
M`8/%`3G3#XWZ`0``1(GWZ.W(__\QR4ACU4R)YDB)Q^B]R?__2(7`#X3,`0``
M3(LX1(LU:EP@`$&+1PPE``0@`#T`!```=))$B??HLLC__TR)_KD"````,=)(
MB<?HT,?__T2+-3E<(`!(B<;I;?___Y!$BS4I7"``1(GWZ('(__](C34Z!0``
MN0,```"Z`0```$B)Q^@HR/__2(7`2(G#=#5(BT`0BSWV6R``2(LHZ$[(__](
MC14)!0``2(G'2(GNZ%S'__](BT,02(L8]D,.0`^%ZP$``(L]Q5L@`.@@R/__
M2(TUX`0``+D#````N@$```!(B<?HQ\?__TB%P$B)PW0]2(T]:@,``#'`3(GN
MZ.[B__](A<!(B<4/A'(!``!(BT,0BSUX6R``2(L8Z-#'__](B>I(B<=(B=[H
MXL;__XL]7%L@`.BWQ___2(TU>00``+H!````2(G'Z,/'__^+/3U;(`!(B</H
ME<?__TB-%6P$``!(B=Y(B<?HH\;__XL]'5L@`.AXQ___2(T]V@(``,:`N0``
M``!,B>XQP.A@XO__2(7`2(G#2(D%:VL@``^$G0```+[``0``2(G?Z'#%__^-
M4`&#^@%V"8/X$0^%#P$``$B+1"0(9$@S!"4H````#X7V````2(/$&%M=05Q!
M74%>05_##Q]``(L5$FL@`$2+-9M:(`"-0O\YZ`^%9_[__X/Z`0^.7O[__[L!
M````9I!$B?>#PP'HU<;__TR)YDB)Q^@:Q?__.1W4:B``1(LU75H@`'_;Z2W^
M__]F#Q]$``!(BSVQ:B``Z%3P__](A<!(B<-(B06O:B``#X5$____2(T]2@0`
M`#'`Z+/&__\/'P"`>`$`#X3U_/__Z>G\__^02(L%<6H@`(L]`UH@`$B+*$B+
M0Q!(BQCH5,;__TB)[DB)W^@)Y___Z8+^__\/'T``BSW:62``Z#7&__](B=Y(
MB<?HBL;__^GZ_?__Z`#%__^)P4B+!1]J(`!(C3WX`P``2(G:2(LP,<#H,\;_
M_P\?`%532(G]2(/L".A"Z___#[802(G#A-)T&@\?A```````2(/``8#Z+P^V
M$$@/1-B$TG7N,<#HY^W__TB%[70=A<!T&8!]``!T$TB-/2\"``"Y!````$B)
MWO.F=`=(@\0(6UW#2(/$"$B)[UM=Z4#D__](C04162``2(7`=`Q(BPCI[,3_
M_P\?0``QR>GAQ/__D$%7059!B?]!54%43(TE;E0@`%5(C2UN5"``4TF)]DF)
MU4PIY4B#[`A(P?T#Z/_"__](A>UT(#';#Q^$``````!,B>I,B?9$B?]!_Q3<
M2(/#`4@YW77J2(/$"%M=05Q!74%>05_#D&8N#Q^$``````#SPP``2(/L"$B#
MQ`C#`````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P
M,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E
M<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2
M.CI086-K97(Z.E9%4E-)3TX`,2XP,S<`+64`+2T`````````7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("```````````'!E<FQX<VDN8P``````
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``````````!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I
M;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@
M)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[
M"F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP
M+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T
M7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO
M9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY
M("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F
M9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD
M;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE
M(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*
M9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S
M("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!
M4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I
M>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL
M87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E
M96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@
M7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&
M2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R
M97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE
M("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B
M+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*
M96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T
M*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA
M<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D
M:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA
M;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H
M+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE
M.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@
M0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ
M1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?
M4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P
M<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@
M)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]4
M14U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`
M05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG
M+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO
M9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A
M9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A
M;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D
M<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P
M,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT
M.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA
M9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T
M(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D
M,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R
M*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL
M97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@
M=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI
M8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2![
M"B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;
M7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T
M.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII
M9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M
M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD
M(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L
M"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)
M3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2([
M"F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S
M*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F
M:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E
M;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*
M?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@
M>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H
M("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP
M;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@
M;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@
M(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P
M96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R
M.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T
M,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE
M*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E
M('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7([
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q
M(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE
M(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R
M:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA
M;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH```````$;`SOL````'````'B#__\X`0``.(?_
M_V`!``!(A___1`8``'B)__\(`0``B(K__W@!``"8H/__R`$``&BA__\4`@``
M^*'__T`"``!(I/__C`(``,BE___8`@``6*;___@"```XI___/`,``&BG__]4
M`P``N*?__VP#``"(J/__F`,``)BH__^L`P``N*K__PP$``#HJO__(`0``-BK
M__]P!```N*W__Y0$```XKO__L`0``&BN___,!```2*___PP%``"HN___Q`4`
M`)B___\0!@``",#__W`&```HP/__B`8``)C`___0!@```````!0`````````
M`7I2``%X$`$;#`<(D`$'$!0````<````:(C__RL``````````````!0`````
M`````7I2``%X$`$;#`<(D`$``"0````<````.(+__\`#````#A!&#AA*#PMW
M"(``/QH[*C,D(@`````4````1````-"%__\(``````````````!,````7```
M``B)__\.%@```$(.$(\"0@X8C@-&#B"-!$(.*(P%1`XPA@9!#CB#!T<.T`4#
MYA4*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P```$@```"L````R)[__\P`````
M0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"
M#B!"#AA"#A!"#@A)"P`H````^````$R?__^$`````$$.$(8"00X8@P-'#C`"
M<PH.&$$.$$$."$$+`$@````D`0``L)___TP"````0@X0CP)"#AB.`T(.((T$
M0@XHC`5!#C"&!D$..(,'2@Y@`R8!"@XX00XP00XH0@X@0@X80@X00@X(1`M(
M````<`$``+2A__]Q`0```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#
M!T<.\`%^"@XX00XP00XH0@X@0@X80@X00@X(1PL`'````+P!``#HHO__@0``
M``!!#A"#`FD*#@A&"P)0#@A`````W`$``%BC___>`````$(.$(X"0@X8C0-%
M#B",!$$.*(8%1`XP@P93#L`@`H0*#C!!#BA!#B!"#AA"#A!"#@A#"Q0````@
M`@``]*/__S``````1`X09PX(`!0````X`@``#*3__TD`````1`X0?0X(`"@`
M``!0`@``1*3__\$`````00X0A@)!#AB#`T<.P$`"IPH.&$$.$$$."$8+$```
M`'P"``#HI/__!0````````!<````D`(``.2D__\:`@```$(.$(\"0@X8C@-"
M#B"-!$(.*(P%1`XPA@9!#CB#!U$.X"`"9`H..$$.,$$.*$(.($(.&$(.$$(.
M"$0+`I8.Z"!+#O`@>0[H($$.X"`````0````\`(``*2F__\J`````````$P`
M```$`P``P*;__^P`````2@X0A@)!#AB#`T0.('4*#AA(PPX00<8."$L+8@H.
M&$C##A!!Q@X(30L"0`X800X000X(1L/&4`X@@P.&`@``(````%0#``!@I___
MVP$```!!#A"#`DL.4`-L`0H.$$$."$<+&````'@#```<J?__=`````!$#B!O
M"@X(10L``!@```"4`P``@*G__R0`````1`X06`H."$0+```\````L`,``)2I
M___<`````$(.$(P"00X8A@-$#B"#!$L.,`)8#CA/#D!N#CA!#C!J"@X@00X8
M00X00@X(00L`M````/`#```TJO__5`P```!"#A"/`D(.&(X#0@X@C01"#BB,
M!40.,(8&00XX@P=.#L"#`@,8`@[(@P)2#M"#`F@.R(,"0@[`@P(#`@$*#CA!
M#C!!#BA"#B!"#AA"#A!"#@A%"P.J`0[(@P)(#M"#`F$.R(,"00[`@P)C#LB#
M`DD.T(,"0@[8@P)$#N"#`ET.P(,"`_L$#LB#`D(.T(,":`[(@P)!#L"#`@-?
M`0H.R(,"0@[0@P)&"T@```"H!```W+7__^T#````0@X0CP)"#AB.`T(.((T$
M0@XHC`5!#C"&!D$..(,'1`Y0`\L""@XX00XP00XH0@X@0@X80@X00@X(10LP
M````]`0``("Y__]P`````$$.$(8"00X8@P-'#B`"5@H.&$$.$$$."$$+1`X8
M1`X000X(*````"@%``#\@/__+0(```!!#A"&`D$.&(,#1`Y0`[T!"@X800X0
M00X(00L4````5`4``)"Y__\?``````````````!$````;`4``)BY__]E````
M`$(.$(\"0@X8C@-%#B"-!$(.*(P%2`XPA@9(#CB#!TT.0'(..$$.,$$.*$(.
M($(.&$(.$$(."``0````M`4``,"Y__\"````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M8"$````````@(0````````````````````````````````````````$`````
M`````0`````````!`````````,L!`````````0`````````:`@````````P`
M````````0!H````````-`````````(17````````&0````````"0JR``````
M`!L`````````"``````````:`````````)BK(```````'``````````(````
M`````/7^_V\`````F`(````````%``````````@-````````!@````````"0
M`P````````H`````````R00````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<`````````N!0````````'`````````"`3````````
M"`````````"8`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````H!(```````#___]O``````(`
M````````\/__;P````#2$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````+BK(```````````````````
M`````````'8:````````AAH```````"6&@```````*8:````````MAH`````
M``#&&@```````-8:````````YAH```````#V&@````````8;````````%AL`
M```````F&P```````#8;````````1AL```````!6&P```````&8;````````
M=AL```````"&&P```````)8;````````IAL```````"V&P```````,8;````
M````UAL```````#F&P```````/8;````````!AP````````6'````````"8<
M````````-AP```````!&'````````%8<````````9AP```````!V'```````
M`(8<````````EAP```````"F'````````+8<````````QAP```````#6'```
M`````.8<````````]AP````````&'0```````!8=````````)AT````````V
M'0```````$8=````````5AT```````!F'0```````'8=````````AAT`````
M``"6'0```````*8=````````MAT```````#&'0```````-8=````````YAT`
M``````#V'0````````8>````````%AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````"P6@```````$=#
M0SH@*%5B=6YT=2`W+C(N,"TQ,G5B=6YT=3$I(#<N,BXP`$=#0SH@*%5B=6YT
M=2`V+C0N,"TX=6)U;G1U,2D@-BXT+C`@,C`Q-S$P,3```"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO
M;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A
M<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN<F\`+F1Y;F%M:6,`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````.`(````````X`@```````!P````````````````````!````
M````````````````$P````<````"`````````%0"````````5`(````````@
M````````````````````!````````````````````"$````'`````@``````
M``!T`@```````'0"````````)`````````````````````0`````````````
M```````T````]O__;P(`````````F`(```````"8`@```````/@`````````
M!0`````````(````````````````````/@````L````"`````````)`#````
M````D`,```````!X"0````````8````!````"``````````8`````````$8`
M```#`````@`````````(#0````````@-````````R00`````````````````
M``$```````````````````!.````____;P(`````````TA$```````#2$0``
M`````,H`````````!0`````````"``````````(`````````6P```/[__V\"
M`````````*`2````````H!(```````"```````````8````"````"```````
M`````````````&H````$`````@`````````@$P```````"`3````````F`$`
M```````%``````````@`````````&`````````!T````!````$(`````````
MN!0```````"X%````````(@%````````!0```!<````(`````````!@`````
M````?@````$````&`````````$`:````````0!H````````7````````````
M````````!````````````````````'D````!````!@````````!@&@``````
M`&`:````````P`,``````````````````!``````````$`````````"$````
M`0````8`````````(!X````````@'@````````@````````````````````(
M``````````@`````````C0````$````&`````````#`>````````,!X`````
M``!2.0``````````````````$````````````````````),````!````!@``
M``````"$5P```````(17````````"0````````````````````0`````````
M``````````"9`````0````(`````````D%<```````"05P```````%@_````
M```````````````(````````````````````H0````$````"`````````.B6
M````````Z)8```````#L````````````````````!```````````````````
M`*\````!`````@````````#8EP```````-B7````````^`4`````````````
M``````@```````````````````"Y````#@````,`````````D*L@``````"0
MJP````````@````````````````````(``````````@`````````Q0````\`
M```#`````````)BK(```````F*L````````(````````````````````"```
M```````(`````````-$````!`````P````````"@JR```````*"K````````
M$P```````````````````!````````````````````#>````!@````,`````
M````N*L@``````"XJP```````!`"````````!@`````````(`````````!``
M````````B`````$````#`````````,BM(```````R*T````````P`@``````
M````````````"``````````(`````````.<````!`````P``````````L"``
M``````"P````````(`````````````````````@```````````````````#M
M````"`````,`````````(+`@```````@L````````(@0````````````````
M```@````````````````````\@````$````P````````````````````(+``
M``````!0`````````````````````0`````````!``````````$````#````
M`````````````````````'"P````````^P````````````````````$`````
+````````````````
